##  Subscriptions
When subscription roles are defined in your workspace, you can add or remove subscribers only under the specific subscription role columns. Adding or removing subscribers under the subscription type columns—accountable, responsible, or observer—will not result in any changes in the workspace when imported. This applies even when selecting a subscription role is not made mandatory in subscriptions settings. To learn more about this setting, see [Enforcing Mandatory Selection of a Subscription Role](https://help.sap.com/docs/leanix/ea/subscription-roles?locale=en-US&state=PRODUCTION&version=CLOUD#loio275af3a27a4410148eada5eb5d54814b__enforcing_mandatory_selection_of_a_subscription_role).
